@@ -6,6 +6,7 @@ package server
 import (
 	"errors"
 	"io/fs"
+	"net"
 	"os"
 )
 
@@ -26,3 +27,7 @@ func removeSocket(path string) (err error) {
 
 	return
 }
+
+func bindSocket(socket string) (net.Listener, error) {
+	return bindUnixSocket(socket)
+}
